# CeRULEo

## Welcome tu CeRULEo

CeRULEo: Comprehensive utilitiEs for Remaining Useful Life Estimation methOds


### Predictive Maintenance

Efficient management of maintenance in modern industrial environments is having a major impact on decreasing costs associated with defective products and equipment inactivity. Therefore, it is critical for companies to develop an efficient and well-implemented maintenance strategy to prevent unexpected outages, improve overall reliability, and reduce operating costs  [@8748978].


The evolution of information systems has transformed traditional manufacturing into factories equipped with intelligent sensors that allow better knowledge about what happens during industrial processes.  All the information collected can be used to optimize decision-making processes. The use of this information in maintenance processes has caused a transition from Preventive Maintenance (PM) techniques to Predictive Maintenance (PdM) methods [@damant2021exploring]. PM  is carried out regularly while the asset is still in a  working condition to prevent sudden breakdowns. In contrast, PdM can statistically assess the health status of a piece of equipment, allowing early detection of pending failures, and enabling timely pre-failure interventions, thanks to prediction models based on historical data. The data-driven methods use condition monitoring data acquired from sensors to provide effective solutions in these areas [@susto2014machine]. 

### Remaining useful life estimation

The remaining useful life (RUL) estimation has been considered as a central technology of PdM [@heimes2008recurrent, @li2018remaining]. RUL estimation is a process that uses prediction methods to forecast the future performance of machinery and obtain the time left before machinery loses its operation ability.

## Bibliography




 
